@@ -1,4 +1,4 @@
-use congee::Art;
+use congee::ArtUsize;
 use rand::{thread_rng, Rng};
 use shumai::{config, ShumaiBench};
 
@@ -15,7 +15,7 @@ pub struct Scan {
 }
 
 struct TestBench {
-    index: Art,
+    index: ArtUsize,
     initial_cnt: usize,
 }
 
@@ -70,7 +70,7 @@ fn main() {
 
     for c in config.iter() {
         let mut test_bench = TestBench {
-            index: Art::new(),
+            index: ArtUsize::new(),
             initial_cnt: 50_000_000,
         };
         let result = shumai::run(&mut test_bench, c, repeat);
